turtles-own
[
  rule                      ;; the turtle's rule (the rules are named by strings)
  origin                    ;; the turtle's original position
  close-turtles             ;; turtles within the accept radius
  far-turtles               ;; turtles within the reject radius
  total-distance-moved      ;; total distance moved by the turtle
  previous-patch            ;; patch the turtle was previously on
  accept-radius             ;; radius that turtles will move together within
  reject-radius             ;; radius that turtles will move apart within
]

;;
;; SETUP AND HELPERS
;;

to setup
  clear-all
  set-default-shape turtles "circle"
  ask patches[    ;; make the grid layout
    ifelse pxcor = 0 or pycor = 0[
      set pcolor gray - 1
    ][
      set pcolor 9.9
    ]
  ]
  make-turtles
  reset-ticks
end

to make-turtles     ;; create the mobile turtles
  if [count patches in-radius initial-radius] of patch 0 0 < num-turtles-to-create
  [ user-message (word "There aren't enough patches in initial-radius to create the number "
                       "of turtles you've asked for.  Please make initial-radius larger or decrease "
                       "the number of turtles.")
    stop ]
  ask patch 0 0 [
      create-initial-turtles move_towards          "towards"       violet
      create-initial-turtles move_away             "away"          yellow
      create-initial-turtles move_towards_away     "towards-away"  green
      create-initial-turtles move_away_towards     "away-towards"  red ]
  set-common-variables
end

;; reports the total number of turtles the user has requested
to-report num-turtles-to-create
  report move_towards +
         move_away +
         move_towards_away +
         move_away_towards
end

;; ask n random patches without a turtle on them that are within initial-radius of the
;; asker to sprout a turtle with the rule set to turtle-rule and color to turtle-color
to create-initial-turtles [n turtle-rule turtle-color]
  ifelse turtle-rule = "fixed"[
    ask n-of n (patches in-radius fixed_spawn_radius with [not any? turtles-here])
  [ sprout 1
    [ set rule turtle-rule
      set color turtle-color ] ]
  ]
  [
    ask n-of n (patches in-radius initial-radius with [not any? turtles-here])
  [ sprout 1
    [ set rule turtle-rule
      set color turtle-color ] ]
  ]
end

;; initializes turtle variables
;; also moves the turtles a bit so that they are a bit more randomly scattered
to set-common-variables
  ask turtles
  [ set xcor xcor - 0.5 + random-float 1
    set ycor ycor - 0.5 + random-float 1
    set origin patch-here
    set total-distance-moved 0
    set accept-radius acceptance-radius
    set reject-radius rejection-radius]
end


;;
;; GO AND TURTLE STRATEGIES
;;

to go
  ask turtles [
    set accept-radius acceptance-radius ; update the accept and reject radius so that they can change on the fly while the model is running
    set reject-radius rejection-radius
    set previous-patch patch-here
    if rule = "towards"   [ move-towards ]
    if rule = "away"       [ move-away ]
    if rule = "towards-away"  [
      move-towards
      move-away
    ]
    if rule = "away-towards"     [
      move-away
      move-towards
    ]
    if rule = "fixed" [
      if ticks < wake_tick [
        die   ; remove oranges if wake-tick was changed live, and is now greater than the current tick
      ]
    ]
    set total-distance-moved (total-distance-moved + (distance previous-patch))
  ]
  if ticks = wake_tick[
    spawn_fixed
  ]
  tick
end

to spawn_fixed      ;; create the fixed turtles
  if [count patches in-radius fixed_spawn_radius] of patch x_spawn y_spawn < fixed
  [ user-message (word "There aren't enough patches in fixed-spawn-radius to create the number "
                       "of turtles you've asked for.  Please make fixed-spawn-radius larger or decrease "
                       "the number of turtles.")
    stop ]
  ask patch x_spawn y_spawn [
      create-initial-turtles fixed "fixed" orange ]
end

;; if a turtle gets to a wall, it turns around
to avoid-walls ;; turtle procedure
  if not can-move? 1
  [ rt 180 ]
end

to move-towards
  set close-turtles other turtles in-radius accept-radius
  if any? close-turtles  ; move if there are turtles to influence me
  [ facexy (mean [xcor] of close-turtles)
    (mean [ycor] of close-turtles)
    avoid-walls
    fd step-size ]
end

to move-away
  set far-turtles other turtles in-radius reject-radius with [not member? myself other turtles in-radius accept-radius]
  if any? far-turtles  ; move if there are turtles to influence me
  [ facexy (mean [xcor] of far-turtles)
    (mean [ycor] of far-turtles)
    rt 180
    avoid-walls
    fd step-size ]
end
@#$#@#$#@
GRAPHICS-WINDOW
274
10
705
442
-1
-1
9.0
1
10
1
1
1
0
0
0
1
-23
23
-23
23
1
1
1
ticks
30.0

SLIDER
36
68
240
101
initial-radius
initial-radius
0
20
20.0
0.5
1
NIL
HORIZONTAL

SLIDER
725
101
920
134
move_towards
move_towards
0
200
42.0
1
1
NIL
HORIZONTAL

SLIDER
1014
45
1210
78
fixed
fixed
0
200
86.0
1
1
NIL
HORIZONTAL

BUTTON
17
19
87
60
NIL
setup
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
97
18
167
59
NIL
go
T
1
T
OBSERVER
NIL
NIL
NIL
NIL
0

SLIDER
725
297
922
330
move_away_towards
move_away_towards
0
200
20.0
1
1
NIL
HORIZONTAL

TEXTBOX
726
83
816
101
Violet
11
0.0
0

TEXTBOX
1014
27
1104
45
Orange
11
0.0
0

TEXTBOX
726
279
816
297
Red
11
0.0
0

PLOT
14
148
263
327
Average Distance from Origin (0,0)
time ticks
average distance
0.0
100.0
0.0
100.0
true
false
"set-plot-x-range 0 30\nset-plot-y-range  0 5 ; set initial y range to half of height" "foreach [ \"towards\" \"away\" \"towards-away\" \"away-towards\" ] [ r ->\n  ;; if there are any turtles with turtle-rule as their rule,\n  ;; plot the mean distance from the origin\n  if any? turtles with [ rule = r ] [\n    set-current-plot-pen r\n    plot mean [ distance patch 0 0 ] of turtles with [ rule = r ]\n  ]\n]"
PENS
"towards" 1.0 0 -8630108 true "" ""
"towards-away" 1.0 0 -10899396 true "" ""
"away" 1.0 0 -1184463 true "" ""
"away-towards" 1.0 0 -2674135 true "" ""

TEXTBOX
725
213
815
231
Green
11
0.0
0

SLIDER
725
229
921
262
move_towards_away
move_towards_away
0
200
19.0
1
1
NIL
HORIZONTAL

TEXTBOX
724
151
814
169
Yellow
11
0.0
0

SLIDER
725
166
921
199
move_away
move_away
0
200
15.0
1
1
NIL
HORIZONTAL

SLIDER
37
107
241
140
step-size
step-size
0.1
2
1.0
0.1
1
NIL
HORIZONTAL

SLIDER
725
12
897
45
acceptance-radius
acceptance-radius
0
20
10.0
1
1
NIL
HORIZONTAL

SLIDER
725
46
897
79
rejection-radius
rejection-radius
0
20
13.0
1
1
NIL
HORIZONTAL

SLIDER
1014
81
1186
114
wake_tick
wake_tick
0
2000
166.0
1
1
NIL
HORIZONTAL

INPUTBOX
1014
116
1169
176
x_spawn
-15.0
1
0
Number

INPUTBOX
1014
177
1169
237
y_spawn
-15.0
1
0
Number

SLIDER
1014
239
1186
272
fixed_spawn_radius
fixed_spawn_radius
0
20
7.5
0.5
1
NIL
HORIZONTAL

PLOT
14
332
270
518
Average Distance from Bot Spawn Point
time ticks
average distance
0.0
10.0
0.0
10.0
true
false
"set-plot-x-range 0 30\nset-plot-y-range  0 5 ; set initial y range to half of height" "foreach [ \"towards\" \"away\" \"towards-away\" \"away-towards\" ] [ r ->\n  ;; if there are any turtles with turtle-rule as their rule,\n  ;; plot the mean distance from the origin\n  if any? turtles with [ rule = r ] [\n    set-current-plot-pen r\n    plot mean [ distance patch x_spawn y_spawn ] of turtles with [ rule = r ]\n  ]\n]"
PENS
"towards" 1.0 0 -8630108 true "" ""
"away" 1.0 0 -1184463 true "" ""
"towards-away" 1.0 0 -10899396 true "" ""
"away-towards" 1.0 0 -2674135 true "" ""

@#$#@#$#@
## WHAT IS IT?

This is a model of polarization, where people have their opinions and can be affected by those around them. This represents how people may interact in real life, and how they influence one another into different opinions. This model also has a fixed group added later on to show how targeted influence can affect others. 

## HOW IT WORKS

This model has several rules implemented to create different types of people, who have different reactions to those around them. 

MOVE_TOWARDS: Move towards the turtles within the acceptance radius. Looks at the average of all the turtle’s positions, and moves towards that. Purple agents only use the move_towards rule, but green and red use it along with the away rule.  

MOVE_AWAY: Moves away from the average position of the turtles within the rejection radius, but outside of the acceptance radius. If too close to the wall, then move away from the wall. Yellow agents only use the move_away rule, but the green and red agents use it along with the towards rule.  

MOVE_TOWARDS_AWAY: These are the green agents, and they follow the towards rule first, and then the away rule.  

MOVE_AWAY_TOWARDS: These are the red agents, and they first follow the away rule, and then the towards rule. 

These agents above all move at the same speed. If not within the range of any agents, then the agents will not move at all.  

The other type of agent is fixed, and it is the orange agents. They are given a spawn radius, an amount, and a spawn location. They are used to influence the other agents. 

## HOW TO USE IT

The sliders on the left side are the initial-radius and step-size variables. The initial-radius slider controls how big the radius is for the initial spawn of the turtles.  

To vary the distance that a turtle moves each time step, change the STEP-SIZE slider.  

Press SETUP to create the number of turtles indicated, in the INITIAL-RADIUS specified. Press GO to start the model and the plots. 

The TICKS monitor displays the number of clock cycles that GO has run. 

On the right side, there are two sliders for acceptance-radius and rejection-radius, which control the distance, in patches, used for the move_towards and move_away rules.  

The 4 sliders beneath the radius sliders control the number of turtles spawned with the specific rules listed.  

## THINGS TO NOTICE

While the model is running, look for the total number of groups the agents form themeselves into, and how many agents are in each group

Then, when the fixed agents appear, see how what effect they have on the different types of agents near them, and where those agents are in relation to the fixed agents.

## THINGS TO TRY

The primary factor that determines how groups are formed in the Accept Radius. For example, a small radius tends to create many small population groups, while a large radius tends to create only a few large groups

## EXTENDING THE MODEL

Additional rules for determining movement could be added, as there are more ways to possibly change someone's opinion

The fixed agents could be made to spawn in two or more locations at once.

The initial agents could have a more detialed and changable procedure for initializing them to their starting locations

## NETLOGO FEATURES

This model generates turtles with the sprout command by having a patch sprout a single turtle. The model looks to make sure that the number of turtles to be created is less than the initial radius, so that no error occurs. Each patch can only spawn one turtle, so more turtles than the initial radius can cause a problem. 

## RELATED MODELS

Scatter by Uri Wilensky - In the NetLogo Library

## CREDITS

Created for the HON 300 Group Modeling project, Northern Illinois University
@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

airplane
true
0
Polygon -7500403 true true 150 0 135 15 120 60 120 105 15 165 15 195 120 180 135 240 105 270 120 285 150 270 180 285 210 270 165 240 180 180 285 195 285 165 180 105 180 60 165 15

arrow
true
0
Polygon -7500403 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

box
false
0
Polygon -7500403 true true 150 285 285 225 285 75 150 135
Polygon -7500403 true true 150 135 15 75 150 15 285 75
Polygon -7500403 true true 15 75 15 225 150 285 150 135
Line -16777216 false 150 285 150 135
Line -16777216 false 150 135 15 75
Line -16777216 false 150 135 285 75

bug
true
0
Circle -7500403 true true 96 182 108
Circle -7500403 true true 110 127 80
Circle -7500403 true true 110 75 80
Line -7500403 true 150 100 80 30
Line -7500403 true 150 100 220 30

butterfly
true
0
Polygon -7500403 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7500403 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7500403 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7500403 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

car
false
0
Polygon -7500403 true true 300 180 279 164 261 144 240 135 226 132 213 106 203 84 185 63 159 50 135 50 75 60 0 150 0 165 0 225 300 225 300 180
Circle -16777216 true false 180 180 90
Circle -16777216 true false 30 180 90
Polygon -16777216 true false 162 80 132 78 134 135 209 135 194 105 189 96 180 89
Circle -7500403 true true 47 195 58
Circle -7500403 true true 195 195 58

circle
false
0
Circle -7500403 true true 0 0 300

circle 2
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240

cow
false
0
Polygon -7500403 true true 200 193 197 249 179 249 177 196 166 187 140 189 93 191 78 179 72 211 49 209 48 181 37 149 25 120 25 89 45 72 103 84 179 75 198 76 252 64 272 81 293 103 285 121 255 121 242 118 224 167
Polygon -7500403 true true 73 210 86 251 62 249 48 208
Polygon -7500403 true true 25 114 16 195 9 204 23 213 25 200 39 123

cylinder
false
0
Circle -7500403 true true 0 0 300

dot
false
0
Circle -7500403 true true 90 90 120

face happy
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240

face neutral
false
0
Circle -7500403 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225

face sad
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183

fish
false
0
Polygon -1 true false 44 131 21 87 15 86 0 120 15 150 0 180 13 214 20 212 45 166
Polygon -1 true false 135 195 119 235 95 218 76 210 46 204 60 165
Polygon -1 true false 75 45 83 77 71 103 86 114 166 78 135 60
Polygon -7500403 true true 30 136 151 77 226 81 280 119 292 146 292 160 287 170 270 195 195 210 151 212 30 166
Circle -16777216 true false 215 106 30

flag
false
0
Rectangle -7500403 true true 60 15 75 300
Polygon -7500403 true true 90 150 270 90 90 30
Line -7500403 true 75 135 90 135
Line -7500403 true 75 45 90 45

flower
false
0
Polygon -10899396 true false 135 120 165 165 180 210 180 240 150 300 165 300 195 240 195 195 165 135
Circle -7500403 true true 85 132 38
Circle -7500403 true true 130 147 38
Circle -7500403 true true 192 85 38
Circle -7500403 true true 85 40 38
Circle -7500403 true true 177 40 38
Circle -7500403 true true 177 132 38
Circle -7500403 true true 70 85 38
Circle -7500403 true true 130 25 38
Circle -7500403 true true 96 51 108
Circle -16777216 true false 113 68 74
Polygon -10899396 true false 189 233 219 188 249 173 279 188 234 218
Polygon -10899396 true false 180 255 150 210 105 210 75 240 135 240

house
false
0
Rectangle -7500403 true true 45 120 255 285
Rectangle -16777216 true false 120 210 180 285
Polygon -7500403 true true 15 120 150 15 285 120
Line -16777216 false 30 120 270 120

leaf
false
0
Polygon -7500403 true true 150 210 135 195 120 210 60 210 30 195 60 180 60 165 15 135 30 120 15 105 40 104 45 90 60 90 90 105 105 120 120 120 105 60 120 60 135 30 150 15 165 30 180 60 195 60 180 120 195 120 210 105 240 90 255 90 263 104 285 105 270 120 285 135 240 165 240 180 270 195 240 210 180 210 165 195
Polygon -7500403 true true 135 195 135 240 120 255 105 255 105 285 135 285 165 240 165 195

line
true
0
Line -7500403 true 150 0 150 300

line half
true
0
Line -7500403 true 150 0 150 150

pentagon
false
0
Polygon -7500403 true true 150 15 15 120 60 285 240 285 285 120

person
false
0
Circle -7500403 true true 110 5 80
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 195 90 240 150 225 180 165 105
Polygon -7500403 true true 105 90 60 150 75 180 135 105

plant
false
0
Rectangle -7500403 true true 135 90 165 300
Polygon -7500403 true true 135 255 90 210 45 195 75 255 135 285
Polygon -7500403 true true 165 255 210 210 255 195 225 255 165 285
Polygon -7500403 true true 135 180 90 135 45 120 75 180 135 210
Polygon -7500403 true true 165 180 165 210 225 180 255 120 210 135
Polygon -7500403 true true 135 105 90 60 45 45 75 105 135 135
Polygon -7500403 true true 165 105 165 135 225 105 255 45 210 60
Polygon -7500403 true true 135 90 120 45 150 15 180 45 165 90

square
false
0
Rectangle -7500403 true true 30 30 270 270

square 2
false
0
Rectangle -7500403 true true 30 30 270 270
Rectangle -16777216 true false 60 60 240 240

star
false
0
Polygon -7500403 true true 151 1 185 108 298 108 207 175 242 282 151 216 59 282 94 175 3 108 116 108

target
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240
Circle -7500403 true true 60 60 180
Circle -16777216 true false 90 90 120
Circle -7500403 true true 120 120 60

tree
false
0
Circle -7500403 true true 118 3 94
Rectangle -6459832 true false 120 195 180 300
Circle -7500403 true true 65 21 108
Circle -7500403 true true 116 41 127
Circle -7500403 true true 45 90 120
Circle -7500403 true true 104 74 152

triangle
false
0
Polygon -7500403 true true 150 30 15 255 285 255

triangle 2
false
0
Polygon -7500403 true true 150 30 15 255 285 255
Polygon -16777216 true false 151 99 225 223 75 224

truck
false
0
Rectangle -7500403 true true 4 45 195 187
Polygon -7500403 true true 296 193 296 150 259 134 244 104 208 104 207 194
Rectangle -1 true false 195 60 195 105
Polygon -16777216 true false 238 112 252 141 219 141 218 112
Circle -16777216 true false 234 174 42
Rectangle -7500403 true true 181 185 214 194
Circle -16777216 true false 144 174 42
Circle -16777216 true false 24 174 42
Circle -7500403 false true 24 174 42
Circle -7500403 false true 144 174 42
Circle -7500403 false true 234 174 42

turtle
true
0
Polygon -10899396 true false 215 204 240 233 246 254 228 266 215 252 193 210
Polygon -10899396 true false 195 90 225 75 245 75 260 89 269 108 261 124 240 105 225 105 210 105
Polygon -10899396 true false 105 90 75 75 55 75 40 89 31 108 39 124 60 105 75 105 90 105
Polygon -10899396 true false 132 85 134 64 107 51 108 17 150 2 192 18 192 52 169 65 172 87
Polygon -10899396 true false 85 204 60 233 54 254 72 266 85 252 107 210
Polygon -7500403 true true 119 75 179 75 209 101 224 135 220 225 175 261 128 261 81 224 74 135 88 99

wheel
false
0
Circle -7500403 true true 3 3 294
Circle -16777216 true false 30 30 240
Line -7500403 true 150 285 150 15
Line -7500403 true 15 150 285 150
Circle -7500403 true true 120 120 60
Line -7500403 true 216 40 79 269
Line -7500403 true 40 84 269 221
Line -7500403 true 40 216 269 79
Line -7500403 true 84 40 221 269

x
false
0
Polygon -7500403 true true 270 75 225 30 30 225 75 270
Polygon -7500403 true true 30 75 75 30 270 225 225 270
@#$#@#$#@
NetLogo 6.2.0
@#$#@#$#@
set too-close 1.5
set too-far 2.0
set num-open-min-max 50
setup
repeat 75 [ go ]
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
default
0.0
-0.2 0 0.0 1.0
0.0 1 1.0 0.0
0.2 0 0.0 1.0
link direction
true
0
Line -7500403 true 150 150 90 180
Line -7500403 true 150 150 210 180
@#$#@#$#@
0
@#$#@#$#@
